@@ -29,6 +29,7 @@ class SeedMetricsLayer:
             self.metrics_layer = metrics_layer
         self.connection = self._init_connection(self.metrics_layer, connection)
         self.database = database if database else self.connection.database
+        self._database_is_not_default = database and database != self.connection.database
         self.schema = schema if schema else self.connection.schema
         self.table = table.replace(".sql", "") if table else None
         if schema and table:
@@ -151,7 +152,20 @@ class SeedMetricsLayer:
         view_folder = loader.zenlytic_project.get("view-paths", [self.default_views_path])[0]
 
         # Dump the models to yaml files
-        ProjectDumper(models, model_folder, views, view_folder).dump(folder)
+        dumper = ProjectDumper(models, model_folder, views, view_folder)
+        dumper.dump(folder)
+
+        # Add the zenlytic_project.yml file if it doesn't exist yet
+        if len(current_models) == 0 and not os.path.exists(os.path.join(folder, "zenlytic_project.yml")):
+            zenlytic_project_path = os.path.join(folder, "zenlytic_project.yml")
+            project_data = {
+                "name": self.connection.name,
+                "profile": self.connection.name,
+                "model-paths": ["models"],
+                "view-paths": ["views"],
+                "dashboard-paths": ["dashboards"],
+            }
+            dumper.dump_yaml_file(project_data, zenlytic_project_path)
 
     def get_model_name(self, current_models: list):
         if len(current_models) > 0:
@@ -173,6 +187,8 @@ class SeedMetricsLayer:
         fields = self.make_fields(column_data) + [count_measure]
         if self.connection.type in {Definitions.snowflake, Definitions.redshift, Definitions.postgres}:
             sql_table_name = f"{schema_name}.{table_name}"
+            if self._database_is_not_default:
+                sql_table_name = f"{self.database}.{sql_table_name}"
         elif self.connection.type == Definitions.bigquery:
             sql_table_name = f"`{self.database}.{schema_name}.{table_name}`"
         else:
@@ -389,8 +405,8 @@ class SeedMetricsLayer:
 
 
 class dbtSeed(SeedMetricsLayer):
-    def seed(self):
-        self.load_manifest()
+    def seed(self, profiles_dir: str = "LOCAL"):
+        self.load_manifest(profiles_dir)
 
         # We need to filter down the whole result to just the chosen schema and table (if applicable)
         if self.table:
@@ -499,7 +515,7 @@ class dbtSeed(SeedMetricsLayer):
         table_names_match = data["TABLE_NAME"].str.lower().isin(table_names)
         return data[schema_matches & table_names_match].copy()
 
-    def load_manifest(self):
+    def load_manifest(self, profiles_dir):
         from metrics_layer.core.parse.github_repo import LocalRepo
         from metrics_layer.core.parse import dbtProjectReader, ProjectLoader
         from metrics_layer.core.parse.manifest import Manifest
@@ -507,8 +523,9 @@ class dbtSeed(SeedMetricsLayer):
         local_repo = LocalRepo(self._location())
         reader = dbtProjectReader(local_repo)
 
-        profiles_dir = os.path.dirname(ProjectLoader.profiles_path())
-        reader.generate_manifest_json(local_repo.folder, profiles_dir)
+        if profiles_dir == "LOCAL":
+            profiles_dir = os.path.dirname(ProjectLoader.profiles_path())
+        reader.generate_manifest_json(reader.dbt_folder, profiles_dir)
         self.manifest = Manifest(reader.load_manifest_json())
         return self.manifest
 
