@@ -3,7 +3,8 @@ class Definitions:
     bigquery = "BIGQUERY"
     redshift = "REDSHIFT"
     postgres = "POSTGRES"
-    supported_warehouses = [snowflake, bigquery, redshift, postgres]
+    druid = "DRUID"
+    supported_warehouses = [snowflake, bigquery, redshift, postgres, druid]
     supported_warehouses_text = ", ".join(supported_warehouses)
 
     does_not_exist = "__DOES_NOT_EXIST__"
