@@ -159,6 +159,8 @@ class Field(MetricsLayerBase, SQLReplacement):
                 alias = f"{self.name}_{self.dimension_group}"
             elif self.type == "duration":
                 alias = f"{self.dimension_group}_{self.name}"
+            else:
+                alias = self.name
         else:
             alias = self.name
         if with_view:
@@ -191,6 +193,7 @@ class Field(MetricsLayerBase, SQLReplacement):
             "count_distinct": self._count_distinct_aggregate_sql,
             "average": self._average_aggregate_sql,
             "average_distinct": self._average_distinct_aggregate_sql,
+            "median": self._median_aggregate_sql,
             "number": self._number_aggregate_sql,
         }
         return type_lookup[self.type](sql, query_type, functional_pk, alias_only)
@@ -237,12 +240,13 @@ class Field(MetricsLayerBase, SQLReplacement):
         return f"COUNT(DISTINCT({sql}))"
 
     def _sum_aggregate_sql(self, sql: str, query_type: str, functional_pk: str, alias_only: bool):
-        if self._needs_symmetric_aggregate(functional_pk):
+        # Druid doesn't support symmetric aggregates, so we have to ignore this check
+        no_symmetric_aggregates = {Definitions.druid}
+        if self._needs_symmetric_aggregate(functional_pk) and query_type not in no_symmetric_aggregates:
             return self._sum_symmetric_aggregate(sql, query_type, alias_only=alias_only)
         return f"SUM({sql})"
 
     def _sum_distinct_aggregate_sql(self, sql: str, query_type: str, functional_pk: str, alias_only: bool):
-        # sql_distinct_key = self._replace_sql_query(self.sql_distinct_key, query_type, alias_only=alias_only)
         sql_distinct_key = self._get_sql_distinct_key(
             self.sql_distinct_key, query_type, alias_only=alias_only
         )
@@ -258,7 +262,12 @@ class Field(MetricsLayerBase, SQLReplacement):
         alias_only: bool = False,
         factor: int = 1_000_000,
     ):
-        if query_type in {Definitions.snowflake, Definitions.redshift}:
+        if query_type in {Definitions.druid}:
+            raise QueryError(
+                "Symmetric aggregates are not supported in Druid. "
+                "Use the 'sum' type instead of 'sum_distinct'."
+            )
+        elif query_type in {Definitions.snowflake, Definitions.redshift}:
             return self._sum_symmetric_aggregate_snowflake(sql, primary_key_sql, alias_only, factor)
         elif query_type == Definitions.bigquery:
             return self._sum_symmetric_aggregate_bigquery(sql, primary_key_sql, alias_only, factor)
@@ -306,7 +315,8 @@ class Field(MetricsLayerBase, SQLReplacement):
         return result
 
     def _count_aggregate_sql(self, sql: str, query_type: str, functional_pk: str, alias_only: bool):
-        if self._needs_symmetric_aggregate(functional_pk):
+        no_symmetric_aggregates = {Definitions.druid}
+        if self._needs_symmetric_aggregate(functional_pk) and query_type not in no_symmetric_aggregates:
             if self.primary_key_count:
                 return self._count_distinct_aggregate_sql(
                     sql, query_type, functional_pk, alias_only=alias_only
@@ -338,14 +348,19 @@ class Field(MetricsLayerBase, SQLReplacement):
         return result
 
     def _average_aggregate_sql(self, sql: str, query_type: str, functional_pk: str, alias_only: bool):
-        if self._needs_symmetric_aggregate(functional_pk):
+        no_symmetric_aggregates = {Definitions.druid}
+        if self._needs_symmetric_aggregate(functional_pk) and query_type not in no_symmetric_aggregates:
             return self._average_symmetric_aggregate(sql, query_type, alias_only=alias_only)
         return f"AVG({sql})"
 
     def _average_distinct_aggregate_sql(
         self, sql: str, query_type: str, functional_pk: str, alias_only: bool
     ):
-        # sql_distinct_key = self._replace_sql_query(self.sql_distinct_key, query_type, alias_only=alias_only)
+        if query_type in {Definitions.druid}:
+            raise QueryError(
+                "Symmetric aggregates are not supported in Druid. "
+                "Use the 'average' type instead of 'average_distinct'."
+            )
         sql_distinct_key = self._get_sql_distinct_key(self.sql_distinct_key, query_type, alias_only)
         return self._average_symmetric_aggregate(
             sql, query_type, primary_key_sql=sql_distinct_key, alias_only=alias_only
@@ -363,6 +378,15 @@ class Field(MetricsLayerBase, SQLReplacement):
         result = f"({sum_symmetric} / {count_symmetric})"
         return result
 
+    def _median_aggregate_sql(self, sql: str, query_type: str, functional_pk: str, alias_only: bool):
+        if query_type in {Definitions.druid, Definitions.postgres, Definitions.bigquery}:
+            raise QueryError(
+                f"Median is not supported in {query_type}. Please choose another "
+                f"aggregate function for the {self.id()} measure."
+            )
+        # Medians do not work with symmetric aggregates, so there's just the one return
+        return f"MEDIAN({sql})"
+
     def _number_aggregate_sql(self, sql: str, query_type: str, functional_pk: str, alias_only: bool):
         if isinstance(sql, list):
             replaced = deepcopy(self.sql)
@@ -492,6 +516,16 @@ class Field(MetricsLayerBase, SQLReplacement):
                 "quarters": lambda start, end: f"{meta_lookup[Definitions.postgres]['years'](start, end)} * 4 + TRUNC(DATE_PART('month', AGE({end}, {start}))/3)",  # noqa
                 "years": lambda start, end: f"DATE_PART('YEAR', AGE({end}, {start}))",
             },
+            Definitions.druid: {
+                "seconds": lambda start, end: f"TIMESTAMPDIFF(SECOND, {start}, {end})",
+                "minutes": lambda start, end: f"TIMESTAMPDIFF(MINUTE, {start}, {end})",
+                "hours": lambda start, end: f"TIMESTAMPDIFF(HOUR, {start}, {end})",
+                "days": lambda start, end: f"TIMESTAMPDIFF(DAY, {start}, {end})",
+                "weeks": lambda start, end: f"TIMESTAMPDIFF(WEEK, {start}, {end})",
+                "months": lambda start, end: f"TIMESTAMPDIFF(MONTH, {start}, {end})",
+                "quarters": lambda start, end: f"TIMESTAMPDIFF(QUARTER, {start}, {end})",
+                "years": lambda start, end: f"TIMESTAMPDIFF(YEAR, {start}, {end})",
+            },
             Definitions.bigquery: {
                 "seconds": lambda start, end: f"TIMESTAMP_DIFF(CAST({end} as TIMESTAMP), CAST({start} as TIMESTAMP), SECOND)",  # noqa
                 "minutes": lambda start, end: f"TIMESTAMP_DIFF(CAST({end} as TIMESTAMP), CAST({start} as TIMESTAMP), MINUTE)",  # noqa
@@ -543,6 +577,19 @@ class Field(MetricsLayerBase, SQLReplacement):
                 "day_of_week": lambda s, qt: f"TO_CHAR(CAST({s} AS TIMESTAMP), 'Dy')",
                 "day_of_month": lambda s, qt: f"EXTRACT('DAY' FROM CAST({s} AS TIMESTAMP))",
             },
+            Definitions.druid: {
+                "raw": lambda s, qt: s,
+                "time": lambda s, qt: f"CAST({s} AS TIMESTAMP)",
+                "date": lambda s, qt: f"DATE_TRUNC('DAY', CAST({s} AS TIMESTAMP))",
+                "week": self._week_dimension_group_time_sql,
+                "month": lambda s, qt: f"DATE_TRUNC('MONTH', CAST({s} AS TIMESTAMP))",
+                "quarter": lambda s, qt: f"DATE_TRUNC('QUARTER', CAST({s} AS TIMESTAMP))",
+                "year": lambda s, qt: f"DATE_TRUNC('YEAR', CAST({s} AS TIMESTAMP))",
+                "month_of_year": lambda s, qt: f"CASE EXTRACT(MONTH FROM {s}) WHEN 1 THEN 'Jan' WHEN 2 THEN 'Feb' WHEN 3 THEN 'Mar' WHEN 4 THEN 'Apr' WHEN 5 THEN 'May' WHEN 6 THEN 'Jun' WHEN 7 THEN 'Jul' WHEN 8 THEN 'Aug' WHEN 9 THEN 'Sep' WHEN 10 THEN 'Oct' WHEN 11 THEN 'Nov' WHEN 12 THEN 'Dec' ELSE 'Invalid Month' END",  # noqa
+                "hour_of_day": lambda s, qt: f"EXTRACT(HOUR FROM CAST({s} AS TIMESTAMP))",
+                "day_of_week": lambda s, qt: f"CASE EXTRACT(DOW FROM {s}) WHEN 1 THEN 'Mon' WHEN 2 THEN 'Tue' WHEN 3 THEN 'Wed' WHEN 4 THEN 'Thu' WHEN 5 THEN 'Fri' WHEN 6 THEN 'Sat' WHEN 7 THEN 'Sun' ELSE 'Invalid Day' END",  # noqa
+                "day_of_month": lambda s, qt: f"EXTRACT(DAY FROM CAST({s} AS TIMESTAMP))",
+            },
             Definitions.bigquery: {
                 "raw": lambda s, qt: s,
                 "time": lambda s, qt: f"CAST({s} AS TIMESTAMP)",
@@ -575,6 +622,9 @@ class Field(MetricsLayerBase, SQLReplacement):
             return f"CAST(CAST(CONVERT_TIMEZONE('{timezone}', {sql}) AS TIMESTAMP) AS {self.datatype.upper()})"  # noqa
         elif query_type == Definitions.postgres:
             return f"CAST(CAST({sql} AS TIMESTAMP) at time zone 'utc' at time zone '{timezone}' AS {self.datatype.upper()})"  # noqa
+        elif query_type == Definitions.druid:
+            print("Warning: Druid does not support timezone conversion. Timezone will be ignored.")
+            return sql
         else:
             raise QueryError(f"Unable to apply timezone to sql for query type {query_type}")
 
@@ -604,7 +654,7 @@ class Field(MetricsLayerBase, SQLReplacement):
             if offset is None:
                 return f"DATE_TRUNC('WEEK', {casted})"
             return f"DATE_TRUNC('WEEK', {casted} + {offset}) - {offset}"
-        elif query_type == Definitions.postgres:
+        elif query_type in {Definitions.postgres, Definitions.druid}:
             if offset is None:
                 return f"DATE_TRUNC('WEEK', CAST({sql} AS TIMESTAMP))"
             return f"DATE_TRUNC('WEEK', CAST({sql} AS TIMESTAMP) + INTERVAL '{offset}' DAY) - INTERVAL '{offset}' DAY"  # noqa
@@ -628,6 +678,58 @@ class Field(MetricsLayerBase, SQLReplacement):
                 f"Field {self.name} is of type duration, but has property "
                 "timeframes when it should have property intervals"
             )
+        if self.field_type == "measure" and not self.canon_date:
+            if self.is_merged_result:
+                error_text = (
+                    f"Field {self.name} is a merged result metric (measure), but does not have a date "
+                    "associated with it. Associate a date with the metric (measure) by setting either "
+                    "the canon_date property on the measure itself or the default_date property on "
+                    "the view the measure is in. Merged results are not possible without associated dates."
+                )
+            else:
+                error_text = (
+                    f"Warning: Field {self.name} is a metric (measure), but does not have a date associated "
+                    "with it. Associate a date with the metric (measure) by setting either the canon_date "
+                    "property on the measure itself or the default_date property on the view the measure "
+                    "is in. Time periods and merged results will not be possible to use until you define "
+                    "the date association"
+                )
+            errors.append(error_text)
+
+        if self.field_type in {"measure", "dimension_group"} and self.type is None:
+            error_text = (
+                f"Field {self.name} is a {self.field_type}, but does not have a type associated "
+                f"with it. You must set a type for this {self.field_type}."
+            )
+            errors.append(error_text)
+
+        if self.sql and self.sql == "${" + self.name + "}":
+            error_text = (
+                f"Field {self.name} references itself in its 'sql' property. You need to reference "
+                "a column using the ${TABLE}.myfield_name syntax or reference another dimension or measure."
+            )
+            errors.append(error_text)
+
+        if self.filters:
+            for f in self.filters:
+                if any(k not in f for k in ["field", "value"]):
+                    key = "value" if "field" in f else "value"
+                    error_text = f"Field {self.name} has a filter {f} that is missing the key {key}."
+                    errors.append(error_text)
+
+        if "." in str(self.view.default_date):
+            view_default_date = self.view.default_date
+        else:
+            view_default_date = f"{self.view.name}.{self.view.default_date}"
+        if self.canon_date is not None and self.canon_date != view_default_date:
+            try:
+                canon_date_field = self.view.project.get_field_by_name(self.canon_date)
+                if canon_date_field.field_type != "dimension_group" or canon_date_field.type != "time":
+                    errors.append(
+                        f"Canon date {self.canon_date} is not of field_type: dimension_group and type: time in field {self.name}."  # noqa
+                    )
+            except (AccessDeniedOrDoesNotExistException, QueryError):
+                errors.append(f"Canon date {self.canon_date} is unreachable in field {self.name}.")
         return errors
 
     def get_referenced_sql_query(self, strings_only=True):
@@ -651,6 +753,9 @@ class Field(MetricsLayerBase, SQLReplacement):
 
     def referenced_fields(self, sql, ignore_explore: bool = False):
         reference_fields = []
+        if sql is None:
+            return []
+
         for to_replace in self.fields_to_replace(sql):
             if to_replace != "TABLE":
                 try:
