@@ -15,6 +15,7 @@ class ConnectionType:
     bigquery = Definitions.bigquery
     redshift = Definitions.redshift
     postgres = Definitions.postgres
+    druid = Definitions.druid
 
 
 class BaseConnection:
@@ -151,6 +152,59 @@ class PostgresConnection(RedshiftConnection):
         self.schema = schema
 
 
+class DruidConnection(BaseConnection):
+    def __init__(
+        self,
+        name: str,
+        host: str,
+        username: str = None,
+        user: str = None,
+        password: str = None,
+        port: int = 8082,
+        path: str = "/druid/v2/sql/",
+        scheme: str = "http",
+        **kwargs,
+    ) -> None:
+        self.type = ConnectionType.druid
+        self.name = name
+        self.host = host
+        self.port = port
+        if user and username:
+            raise ArgumentError(
+                "Received arguments for both user and username, "
+                "please send only one argument for the Druid user"
+            )
+        elif username:
+            self.user = username
+        elif user:
+            self.user = user
+        self.password = password
+        self.path = path
+        self.scheme = scheme
+
+    def to_dict(self):
+        base = {
+            "name": self.name,
+            "host": self.host,
+            "port": self.port,
+            "path": self.path,
+            "scheme": self.scheme,
+            "type": self.type,
+        }
+        if self.user:
+            base["user"] = self.user
+        if self.password:
+            base["password"] = self.password
+        return base
+
+    def printable_attributes(self):
+        attributes = deepcopy(self.to_dict())
+        attributes.pop("password")
+        attributes["name"] = self.name
+        sort_order = ["name", "type", "host", "port", "user", "path", "scheme"]
+        return {key: attributes.get(key) for key in sort_order if attributes.get(key) is not None}
+
+
 class BigQueryConnection(BaseConnection):
     def __init__(
         self, name: str, schema: str = None, credentials: str = None, keyfile: str = None, **kwargs
@@ -161,6 +215,7 @@ class BigQueryConnection(BaseConnection):
         creds_to_use = credentials if credentials else keyfile
         self.credentials = self._convert_json_if_needed(creds_to_use, kwargs)
         self.project_id = self.credentials["project_id"]
+        self.database = self.project_id
 
     def to_dict(self):
         """Dict for use with the BigQuery connector"""
@@ -196,3 +251,12 @@ class BigQueryConnection(BaseConnection):
                     return json.load(f)
         else:
             raise TypeError(f"BigQuery credentials json had wrong type: {type(creds)} for value {creds}")
+
+
+connection_class_lookup = {
+    ConnectionType.snowflake: SnowflakeConnection,
+    ConnectionType.redshift: RedshiftConnection,
+    ConnectionType.bigquery: BigQueryConnection,
+    ConnectionType.postgres: PostgresConnection,
+    ConnectionType.druid: DruidConnection,
+}
