@@ -7,6 +7,7 @@ import networkx
 from metrics_layer.core.exceptions import JoinError
 from metrics_layer.core.model.base import MetricsLayerBase
 from metrics_layer.core.model.definitions import Definitions
+from metrics_layer.core.model.filter import Filter
 
 
 class MetricsLayerDesign:
@@ -70,10 +71,19 @@ class MetricsLayerDesign:
 
             g = self.project.join_graph.graph
             raw_edges = networkx.line_graph(g).nodes
+            bridge_views = self._bridge_views(required_views)
             sub_line_graph_nodes = networkx.line_graph(self._join_subgraph).nodes
             edges = [e for e in raw_edges if e[0] in required_views or e[1] in required_views]
-            # Sorting puts the edges in the subgraph first, then sorts alphabetically
-            for view_pair in sorted(edges, key=lambda x: (int(x in sub_line_graph_nodes) * -1, x)):
+            sorted_edges = sorted(
+                edges,
+                key=lambda x: (
+                    int(any(i in bridge_views for i in x)) * -1,
+                    int(x in sub_line_graph_nodes) * -1,
+                    x,
+                ),
+            )
+            # Sorting puts the bridge views first, edges in the subgraph next, then sorts alphabetically
+            for view_pair in sorted_edges:
                 try:
                     return self._greedy_build_join(g, view_pair, required_views)
                 except ValueError:
@@ -81,6 +91,13 @@ class MetricsLayerDesign:
 
             raise networkx.exception.NetworkXNoPath
 
+    def _bridge_views(self, required_views: list):
+        bridge_views = []
+        for k, v in self.project.join_graph.composite_keys.items():
+            if any(r in k for r in required_views):
+                bridge_views.append(v)
+        return bridge_views
+
     def _validate_join_path(self, pairs: list, required_views: list):
         added_views = []
         for i, (v1, v2) in enumerate(pairs):
@@ -243,13 +260,22 @@ class MetricsLayerDesign:
             if view.access_filters:
                 for condition_set in view.access_filters:
                     field = self.project.get_field(condition_set["field"])
-                    sql = field.sql_query(self.query_type)
+                    field_sql = field.sql_query(self.query_type)
                     user_attribute_value = condition_set["user_attribute"]
-
                     if self.project._user and self.project._user.get(user_attribute_value):
-                        condition = f"{sql} = '{self.project._user[user_attribute_value]}'"
-                        conditions.append(condition)
+                        f = Filter(
+                            {
+                                "field": condition_set["field"],
+                                "value": self.project._user[user_attribute_value],
+                            }
+                        )
                         fields.append(field)
+                        for filter_dict in f.filter_dict():
+                            filter_sql = Filter.sql_query(
+                                field_sql, filter_dict["expression"], filter_dict["value"]
+                            )
+                            print(filter_sql)
+                            conditions.append(str(filter_sql))
 
         if conditions and fields:
             return " and ".join(conditions), fields
